package com.jqtx.windows.utils;

import cn.hutool.core.lang.UUID;
import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.jqtx.windows.component.model.ZyHttpBaseResponse;
import com.jqtx.windows.component.model.ZyHttpBaseRquest;
import com.jqtx.windows.web.request.AbcRequest;
import com.jqtx.windows.web.response.JsonResult;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.time.LocalDateTime;

@Slf4j
@Component
public class AbcHttpClient {


    @Value("${zhenong.url}")
    private String posetUrl;
    @Value("${zhenong.yyPrivateKey}")
    private String privateKey;

    @Value("${zhenong.publicKey}")
    private String ypdPublicKey;

    @Value("${zhenong.clientId}")
    private String clientId;


    public ZyHttpBaseResponse postRequest(String paramJson, String method) {
        try {
            final String url = posetUrl;
            ZyHttpBaseRquest zyHttpBaseRquest = new ZyHttpBaseRquest();
            zyHttpBaseRquest.setClientld(clientId);
            zyHttpBaseRquest.setServiceld(method);
            zyHttpBaseRquest.setSegNo(UUID.fastUUID().toString());
            zyHttpBaseRquest.setTransDateTime(LocalDateTime.now().toString());
            String responseParam = EncryptUtil.encrypt(paramJson, AbcRsaUtil.getPublicKey(ypdPublicKey));
            String responseSign = SignUtil.sign(responseParam, AbcRsaUtil.getPrivateKey(privateKey));
            zyHttpBaseRquest.setData(responseParam);
            zyHttpBaseRquest.setSign(responseSign);
            log.info("请求浙农未加密数据:{}", JSON.toJSONString(paramJson));
            log.info("请求浙农加密数据:{}", JSON.toJSONString(zyHttpBaseRquest));
            log.info("请求浙农url:{}", url);
            HttpResponse response = HttpRequest.post(url).body(JSON.toJSONString(zyHttpBaseRquest)).setConnectionTimeout(5000).execute();
            log.info("请求浙农加密返回数据:{}", JSON.toJSONString(response.body()));
            if (response.getStatus() == 200 && StringUtils.isNotBlank(response.body())) {
                final String body = response.body();
                JSONObject responseJson = JSONObject.parseObject(body);
                String data = responseJson.getString("data");
                String sign = responseJson.getString("sign");
                boolean f = SignUtil.veriSign(data, sign, AbcRsaUtil.getPublicKey(ypdPublicKey));
                if (f) {
                    String dec = EncryptUtil.decrypt(data, AbcRsaUtil.getPrivateKey(privateKey));
                    log.info("请求浙农解密返回数据:{}", JSON.toJSONString(dec));
                    return JSONObject.parseObject(dec, ZyHttpBaseResponse.class);
                } else {
                    log.info("验签异常");
                }
            } else {
                throw new Exception("请求异常");
            }
        } catch (Exception e) {
            log.error("请求浙农异常:{}", e.getMessage(), e);
            return null;
        }
        return null;
    }
}
